measuretools.pad_measures_in_expr_with_skips
============================================

.. autofunction:: abjad.tools.measuretools.pad_measures_in_expr_with_skips.pad_measures_in_expr_with_skips
   :noindex:
